==> 0.4.72.tar.gz: lib/image_url.dart <==
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:wowit/common.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/sql_service.dart';

class ImageByID {
  ImageByID._();

  static const String prefsImage = 'prefImage';

  static const String _splitValue = '[..]';
  static const String _splitData = '[,,]';

  static const Map<String, Object> _defaultData = {
    'hinhAnh_image_path': Common.DEFAULT_IMAGE_URL,
  };

  /// [value] có thể là id ảnh (ID) hoặc tên ảnh (String)
  ///
  /// Ví dụ:
  /// ```dart
  /// ImageByID.getUrlImage(12)
  ///
  /// ImageByID.getUrlImage('logo_8xland.png')
  /// ```
  static String getUrlImage(
    dynamic value, {
    String defaultUrl = Common.DEFAULT_IMAGE_URL,
  }) {
    if (value == null) return defaultUrl;
    if (value is int && Common.mapImage.containsKey(value.toString())) {
      Map<String, Object> data =
          Common.mapImage[value.toString()] as Map<String, Object>;
      String pathKey = data.keys.firstWhere(
        (element) => element.endsWith('_image_path'),
        orElse: () => data.keys.firstWhere(
          (element) => element.endsWith('_path'),
          orElse: () => '',
        ),
      );
      if (pathKey.isEmpty) return defaultUrl;
      return Methods.getString(data, pathKey);
    }
    if (value is String) {
      value = value.trim();
      for (Map<String, Object?> data in Common.mapImage.values) {
        String nameKey = data.keys.firstWhere(
          (element) => element.endsWith('_image_name'),
          orElse: () => data.keys.firstWhere(
            (element) => element.endsWith('_image_path'),
            orElse: () => '',
          ),
        );
        if (nameKey.isEmpty) continue;

        String name = Methods.getString(data, nameKey);
        if (nameKey.endsWith('_path')) {
          name = name.split('/').last;
        }
        name = name.trim();
        if (name == value) {
          String pathKey = data.keys.firstWhere(
            (element) => element.endsWith('_image_path'),
            orElse: () => data.keys.firstWhere(
              (element) => element.endsWith('_path'),
              orElse: () => '',
            ),
          );
          if (pathKey.isEmpty) return defaultUrl;
          return Methods.getString(data, pathKey);
        }
      }
    }
    return defaultUrl;
  }

  /// [value] có thể là id ảnh (ID) hoặc tên ảnh (String)
  ///
  /// Ví dụ:
  /// ```
  /// ImageByID.getDataImage(12)
  ///
  /// ImageByID.getDataImage('logo_8xland.png')
  /// ```
  static Map<String, Object?> getDataImage(
    dynamic value, {
    Map<String, Object?> defaultData = _defaultData,
  }) {
    if (value == null) return defaultData;
    if (value is int && Common.mapImage.containsKey(value.toString())) {
      Map<String, Object> data =
          Common.mapImage[value.toString()] as Map<String, Object>;
      return data;
    }
    if (value is String) {
      for (Map<String, Object?> data in Common.mapImage.values) {
        String nameKey = data.keys.firstWhere(
          (element) => element.endsWith('_image_name'),
          orElse: () => data.keys.firstWhere(
            (element) => element.endsWith('_image_path'),
            orElse: () => '',
          ),
        );
        if (nameKey.isEmpty) continue;

        String name = Methods.getString(data, nameKey);
        if (nameKey.endsWith('_image_path')) {
          name = name.split('/').last;
        }
        if (name == value) {
          return data;
        }
      }
    }
    return defaultData;
  }

  static Future<void> initHinhAnh({
    List<Map<String, Object?>>? dtImage,
    bool reload = false,
  }) async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      if (prefs.getStringList(prefsImage) == null || reload) {
        if (dtImage == null || dtImage.isEmpty || reload) {
          var data = await SQLService.execute(
            'sp_getImage',
          );
          dtImage = Methods.getList(data, 'dsHinhAnh');
        }
        if (Common.uid > 0) {
          await SQLService.execute(
            'sp_setHasMapImage',
            params: {'@uid': Common.uid},
          );
        }
        saveImageToLocal(dsImage: dtImage);
        Common.mapImage = {
          for (var value in dtImage) Methods.getString(value, 'ID'): value
        };
      } else {
        loadImageFromLocal();
      }
    } catch (ex) {
      if (kDebugMode) {
        print('ImageByID.initHinhAnh exception: ' + ex.toString());
      }
    }
  }

  static saveImageToLocal({
    required List<Map<String, Object?>> dsImage,
  }) async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      List<String> images = dsImage.map<String>((e) {
        return e.entries.map((e) {
          String value = e.value != null ? e.value.toString() : '';
          return e.key + _splitValue + value;
        }).join(_splitData);
      }).toList();
      await prefs.setStringList(prefsImage, images);
      if (kDebugMode) {
        print('save Images to local success');
      }
    } catch (e) {
      if (kDebugMode) {
        print('ImageByID.saveImageToLocal exception: ' + e.toString());
      }
    }
  }

  static loadImageFromLocal() async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      List<String> listString = prefs.getStringList(prefsImage) ?? [];
      List<Map<String, Object>> listData = List.generate(
        listString.length,
        (index) => {
          for (var value in listString[index].split(_splitData))
            value.split(_splitValue)[0]: value.split(_splitValue)[1]
        },
      );
      Common.mapImage = {
        for (var data in listData) Methods.getString(data, 'ID'): data
      };
      if (kDebugMode) {
        print('load Images from local success');
      }
    } catch (e) {
      if (kDebugMode) {
        print('ImageByID.loadImageFromLocal exception: ' + e.toString());
      }
    }
  }
}

==> 0.5.6.tar.gz: lib/image_url.dart <==
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:wowit/common.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/sql_service.dart';

class ImageByID {
  ImageByID._();

  static const String prefsImage = 'prefImage';

  static const String _splitValue = '[..]';
  static const String _splitData = '[,,]';

  static const Map<String, Object> _defaultData = {
    'hinhAnh_image_path': Common.DEFAULT_IMAGE_URL,
  };

  /// [value] có thể là id ảnh (ID) hoặc tên ảnh (String)
  ///
  /// Ví dụ:
  /// ```dart
  /// ImageByID.getUrlImage(12)
  ///
  /// ImageByID.getUrlImage('logo_8xland.png')
  /// ```
  static String getUrlImage(
    dynamic value, {
    String defaultUrl = Common.DEFAULT_IMAGE_URL,
  }) {
    if (value == null) return defaultUrl;
    if (value is int && Common.mapImage.containsKey(value.toString())) {
      Map<String, Object> data =
          Common.mapImage[value.toString()] as Map<String, Object>;
      String pathKey = data.keys.firstWhere(
        (element) => element.endsWith('_image_path'),
        orElse: () => data.keys.firstWhere(
          (element) => element.endsWith('_path'),
          orElse: () => '',
        ),
      );
      if (pathKey.isEmpty) return defaultUrl;
      return Methods.getString(data, pathKey);
    }
    if (value is String) {
      value = value.trim();
      for (Map<String, Object?> data in Common.mapImage.values) {
        String nameKey = data.keys.firstWhere(
          (element) => element.endsWith('_image_name'),
          orElse: () => data.keys.firstWhere(
            (element) => element.endsWith('_image_path'),
            orElse: () => '',
          ),
        );
        if (nameKey.isEmpty) continue;

        String name = Methods.getString(data, nameKey);
        if (nameKey.endsWith('_path')) {
          name = name.split('/').last;
        }
        name = name.trim();
        if (name == value) {
          String pathKey = data.keys.firstWhere(
            (element) => element.endsWith('_image_path'),
            orElse: () => data.keys.firstWhere(
              (element) => element.endsWith('_path'),
              orElse: () => '',
            ),
          );
          if (pathKey.isEmpty) return defaultUrl;
          return Methods.getString(data, pathKey);
        }
      }
    }
    return defaultUrl;
  }

  /// [value] có thể là id ảnh (ID) hoặc tên ảnh (String)
  ///
  /// Ví dụ:
  /// ```
  /// ImageByID.getDataImage(12)
  ///
  /// ImageByID.getDataImage('logo_8xland.png')
  /// ```
  static Map<String, Object?> getDataImage(
    dynamic value, {
    Map<String, Object?> defaultData = _defaultData,
  }) {
    if (value == null) return defaultData;
    if (value is int && Common.mapImage.containsKey(value.toString())) {
      Map<String, Object> data =
          Common.mapImage[value.toString()] as Map<String, Object>;
      return data;
    }
    if (value is String) {
      for (Map<String, Object?> data in Common.mapImage.values) {
        String nameKey = data.keys.firstWhere(
          (element) => element.endsWith('_image_name'),
          orElse: () => data.keys.firstWhere(
            (element) => element.endsWith('_image_path'),
            orElse: () => '',
          ),
        );
        if (nameKey.isEmpty) continue;

        String name = Methods.getString(data, nameKey);
        if (nameKey.endsWith('_image_path')) {
          name = name.split('/').last;
        }
        if (name == value) {
          return data;
        }
      }
    }
    return defaultData;
  }

  static Future<void> initHinhAnh({
    List<Map<String, Object?>>? dtImage,
    bool reload = false,
  }) async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      if (prefs.getStringList(prefsImage) == null || reload) {
        if (dtImage == null || dtImage.isEmpty || reload) {
          var data = await SQLService.execute(
            'sp_getImage',
          );
          dtImage = Methods.getList(data, 'dsHinhAnh');
        }
        if (Common.uid > 0) {
          await SQLService.execute(
            'sp_setHasMapImage',
            params: {'@uid': Common.uid},
          );
        }
        saveImageToLocal(dsImage: dtImage);
        Common.mapImage = {
          for (var value in dtImage) Methods.getString(value, 'ID'): value
        };
      } else {
        loadImageFromLocal();
      }
    } catch (ex) {
      if (kDebugMode) {
        print('ImageByID.initHinhAnh exception: $ex');
      }
    }
  }

  static saveImageToLocal({
    required List<Map<String, Object?>> dsImage,
  }) async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      List<String> images = dsImage.map<String>((e) {
        return e.entries.map((e) {
          String value = e.value != null ? e.value.toString() : '';
          return e.key + _splitValue + value;
        }).join(_splitData);
      }).toList();
      await prefs.setStringList(prefsImage, images);
      if (kDebugMode) {
        print('save Images to local success');
      }
    } catch (e) {
      if (kDebugMode) {
        print('ImageByID.saveImageToLocal exception: $e');
      }
    }
  }

  static loadImageFromLocal() async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      List<String> listString = prefs.getStringList(prefsImage) ?? [];
      List<Map<String, Object>> listData = List.generate(
        listString.length,
        (index) => {
          for (var value in listString[index].split(_splitData))
            value.split(_splitValue)[0]: value.split(_splitValue)[1]
        },
      );
      Common.mapImage = {
        for (var data in listData) Methods.getString(data, 'ID'): data
      };
      if (kDebugMode) {
        print('load Images from local success');
      }
    } catch (e) {
      if (kDebugMode) {
        print('ImageByID.loadImageFromLocal exception: $e');
      }
    }
  }
}
